"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const ava_1 = require("ava");
const util = require("util");
const cproc = require("child_process");
const exec = util.promisify(cproc.exec);
ava_1.default('starts sandbox server', (t) => __awaiter(this, void 0, void 0, function* () {
    const command = `./bin/specron sandbox --port 8546 --ttl 1000`;
    const { stdout, stderr } = yield exec(command);
    t.true(stdout.indexOf('localhost:8546') !== -1);
    t.true(stderr === '');
}));
ava_1.default('initializes current folder', (t) => __awaiter(this, void 0, void 0, function* () {
    const cwd = `./node_modules/.tmp/init-${Date.now()}`;
    const command = `mkdir -p ${cwd}; cd ${cwd}; ../../../bin/specron init --name foo --description bar; echo code: $?`;
    const { stdout, stderr } = yield exec(command);
    t.true(stdout.indexOf('Continue by running the commands below:') !== -1);
    t.true(stdout.indexOf('code: 0') !== -1);
    t.true(stderr === '');
}));
ava_1.default('compiles smart contracts', (t) => __awaiter(this, void 0, void 0, function* () {
    const dist = `./node_modules/.tmp/compile-${Date.now()}`;
    const command = `./bin/specron compile --severities error warning --match ./src/tests/assets/*.sol --build ${dist}; echo code: $?`;
    const { stdout, stderr } = yield exec(command);
    t.true(stdout.indexOf('Contracts') !== -1);
    t.true(stdout.indexOf('code: 0') !== -1);
    t.true(stderr === '');
}));
ava_1.default.serial('runs valid tests', (t) => __awaiter(this, void 0, void 0, function* () {
    const command = `./bin/specron test --match ./src/tests/assets/valid.hay.ts --require ts-node/register; echo code: $?`;
    const { stdout, stderr } = yield exec(command);
    t.true(stdout.indexOf('code: 0') !== -1);
    t.true(stderr === '');
}));
ava_1.default.serial('runs invalid tests', (t) => __awaiter(this, void 0, void 0, function* () {
    const command = `./bin/specron test --match ./src/tests/assets/invalid.hay.ts --require ts-node/register; echo code: $?`;
    const { stdout, stderr } = yield exec(command);
    t.true(stdout.indexOf('src/tests/assets/invalid.hay.ts') !== -1);
    t.true(stdout.indexOf('code: 1') !== -1);
    t.true(stderr === '');
}));
//# sourceMappingURL=index.test.js.map